@@ -19,7 +19,7 @@ except ImportError:
     PLOTTING = False
 
 
-__version__ = '0.3.1'
+__version__ = '0.3.2'
 
 """
 Copyright 2018, Alexander J. Tarashansky, All rights reserved.
@@ -139,6 +139,7 @@ class SAM(object):
         if counts is not None:
             self.sparse_data,self.all_gene_names,self.all_cell_names = counts
             self.D = self.sparse_data.copy()
+            self.D2= self.D.copy()
             self.gene_names=self.all_gene_names
             self.cell_names=self.all_cell_names
                   
@@ -1025,16 +1026,21 @@ class SAM(object):
             All keyword arguments in 'show_gene_expression' and 'scatter'
             are eligible.
         """
-        name = np.where(self.all_gene_names == name)[0]
-        if(name.size == 0):
+        if((self.all_gene_names==name).sum()==0):
             print(
-                "Gene note found in the filtered dataset. Note that genes "
+                "Gene not found in the filtered dataset. Note that genes "
                 "are case sensitive.")
             return
         sds = self.corr_bin_genes(input_gene=name, number_of_features=2000)
-
-        for i in range(1, n_genes+1):
+        
+        if (n_genes+1 > sds[0].size):
+            x = sds[0].size
+        else:
+            x = n_genes+1
+            
+        for i in range(1,x):
             self.show_gene_expression(sds[0][i], **kwargs)
+            
         return sds[0][1:]
 
     def corr_bin_genes(self, number_of_features=None, input_gene=None):
@@ -1066,13 +1072,12 @@ class SAM(object):
                 number_of_features = 5000;
                 
             if(input_gene is not None):
-                if(type(input_gene) is str):
-                    input_gene = np.where(self.all_gene_names == input_gene)[0]
-                    if(input_gene.size == 0):
-                        print(
-                            "Gene note found in the filtered dataset. Note "
-                            "that genes are case sensitive.")
-                        return
+                input_gene = np.where(self.all_gene_names == input_gene)[0]
+                if(input_gene.size == 0):
+                    print(
+                        "Gene note found in the filtered dataset. Note "
+                        "that genes are case sensitive.")
+                    return
                 seeds = [np.array([input_gene])]
                 pw_corr = np.corrcoef(
                     self.D_avg[:, idx2[:number_of_features]].T.toarray())
